@@ -1,6 +1,6 @@
 package Koha::Contrib::Tamil::Indexer;
 {
-  $Koha::Contrib::Tamil::Indexer::VERSION = '0.008';
+  $Koha::Contrib::Tamil::Indexer::VERSION = '0.009';
 }
 # ABSTRACT: Class doing Zebra Koha indexing
 
@@ -10,6 +10,7 @@ use Carp;
 use Koha::Contrib::Tamil::Koha;
 use Koha::Contrib::Tamil::RecordReader;
 use Koha::Contrib::Tamil::RecordWriter::File::Marcxml;
+use Koha::Contrib::Tamil::RecordWriter::File::Iso2709;
 use Koha::Contrib::Tamil::Conversion;
 use File::Path;
 use Locale::TextDomain 'Koha-Contrib-Tamil';
@@ -101,10 +102,13 @@ sub run {
             select => $is_full_indexing ? 'all' : 'queue_update',
             xml    => '1'
         ),
-        writer => Koha::Contrib::Tamil::RecordWriter::File::Marcxml->new(
-            file    => "$from_dir/update/records",
-            binmode => 'utf8'
-        ),
+        writer => $is_biblio_indexing 
+            ? Koha::Contrib::Tamil::RecordWriter::File::Marcxml->new(
+                file    => "$from_dir/update/records",
+                binmode => 'utf8' )
+            : Koha::Contrib::Tamil::RecordWriter::File::Iso2709->new(
+                file    => "$from_dir/update/records",
+                binmode => 'utf8' ),
         blocking    => $self->blocking,
         verbose     => $self->verbose,
     );
@@ -120,10 +124,13 @@ sub run {
                 select => 'queue_delete',
                 xml    => '1'
             ),
-            writer => Koha::Contrib::Tamil::RecordWriter::File::Marcxml->new(
-                file    => "$from_dir/delete/records",
-                binmode => 'utf8'
-            ),
+            writer => $is_biblio_indexing
+                ? Koha::Contrib::Tamil::RecordWriter::File::Marcxml->new(
+                    file    => "$from_dir/delete/records",
+                    binmode => 'utf8' )
+                : Koha::Contrib::Tamil::RecordWriter::File::Iso2709->new(
+                    file    => "$from_dir/delete/records",
+                    binmode => 'utf8' ),
             blocking    => $self->blocking,
             verbose     => $self->verbose,
         );
@@ -184,7 +191,7 @@ Koha::Contrib::Tamil::Indexer - Class doing Zebra Koha indexing
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 METHODS
 
