@@ -1,6 +1,6 @@
 package Koha::Contrib::Tamil::RecordWriter::File::Iso2709;
 {
-  $Koha::Contrib::Tamil::RecordWriter::File::Iso2709::VERSION = '0.008';
+  $Koha::Contrib::Tamil::RecordWriter::File::Iso2709::VERSION = '0.009';
 }
 #ABSTRACT: ISO2709 MARC records writer
 use Moose;
@@ -24,14 +24,25 @@ sub write {
     my ( $self, $record ) = @_;
 
     $self->SUPER::write();
-
     my $fh = $self->fh;
-    print $fh $record->as_usmarc(); 
+
+    if ( ref($record) eq 'MARC::Record' ) {
+        print $fh $record->as_usmarc(); 
+    }
+    else {
+        my $rec = MARC::Record::new_from_xml( $record, "utf8" );
+        my $leader = $rec->leader;
+        if ( length($leader) > 24 ) {
+            $rec->leader( substr($leader, 0, 24) );
+        }
+        print $fh $rec->as_usmarc;
+    }
 }
 
 __PACKAGE__->meta->make_immutable;
 
-1
+1;
+
 
 __END__
 =pod
@@ -44,7 +55,7 @@ Koha::Contrib::Tamil::RecordWriter::File::Iso2709 - ISO2709 MARC records writer
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 AUTHOR
 
